##############################################################################  
#   
# Zope Public License (ZPL) Version 0.9.7  
# ---------------------------------------  
#   
# Copyright (c) Digital Creations.  All rights reserved.  
#   
# This license has been certified as Open Source(tm).  
#   
# Redistribution and use in source and binary forms, with or without  
# modification, are permitted provided that the following conditions are  
# met:  
#   
# 1. Redistributions in source code must retain the above copyright  
#    notice, this list of conditions, and the following disclaimer.  
#   
# 2. Redistributions in binary form must reproduce the above copyright  
#    notice, this list of conditions, and the following disclaimer in  
#    the documentation and/or other materials provided with the  
#    distribution.  
#   
# 3. Digital Creations requests that attribution be given to Zope  
#    in any manner possible. Zope includes a "Powered by Zope"  
#    button that is installed by default. While it is not a license  
#    violation to remove this button, it is requested that the  
#    attribution remain. A significant investment has been put  
#    into Zope, and this effort will continue if the Zope community  
#    continues to grow. This is one way to assure that growth.  
#   
# 4. All advertising materials and documentation mentioning  
#    features derived from or use of this software must display  
#    the following acknowledgement:  
#   
#      "This product includes software developed by Digital Creations  
#      for use in the Z Object Publishing Environment  
#      (http://www.zope.org/)."  
#   
#    In the event that the product being advertised includes an  
#    intact Zope distribution (with copyright and license included)  
#    then this clause is waived.  
#   
# 5. Names associated with Zope or Digital Creations must not be used to  
#    endorse or promote products derived from this software without  
#    prior written permission from Digital Creations.  
#   
# 6. Modified redistributions of any form whatsoever must retain  
#    the following acknowledgment:  
#   
#      "This product includes software developed by Digital Creations  
#      for use in the Z Object Publishing Environment  
#      (http://www.zope.org/)."  
#   
#    Intact (re-)distributions of any official Zope release do not  
#    require an external acknowledgement.  
#   
# 7. Modifications are encouraged but must be packaged separately as  
#    patches to official Zope releases.  Distributions that do not  
#    clearly separate the patches from the original work must be clearly  
#    labeled as unofficial distributions.  Modifications which do not  
#    carry the name Zope may be packaged in any form, as long as they  
#    conform to all of the clauses above.  
#   
#   
# Disclaimer  
#   
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY  
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE  
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR  
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS  
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,  
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT  
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF  
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND  
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,  
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF  
#   SUCH DAMAGE.  
#   
#   
# This software consists of contributions made by Digital Creations and  
# many individuals on behalf of Digital Creations.  Specific  
# attributions are listed in the accompanying credits file.  
#   
##############################################################################  
#   
# Portions Copyright (c) 1999 by Butch Landingin.  
#   
# Redistribution and use in source and binary forms, with or without  
# modification, are permitted provided that the following conditions  
# are met:  
# 1. Redistributions of source code must retain the above copyright  
#    including the original copyright, this copyright notice, the list of   
#    conditions and the following disclaimer.  
# 2. Redistributions in binary form must reproduce the above copyright  
#    including the original copyright, this copyright notice, the list of   
#    conditions and the following disclaimer in the  
#    documentation and/or other materials provided with the distribution.  
# 3. The name of the author may not be used to endorse or promote products  
#    derived from this software without specific prior written permission  
#  
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR  
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,  
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,  
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY  
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT  
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF  
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.  
#    
#  In accordance with the license provided for by the software upon  
#  which some of the source code has been derived or used, the following   
#  acknowledgement is hereby provided :  
#  
#      "This product includes software developed by Digital Creations  
#      for use in the Z Object Publishing Environment  
#      (http://www.zope.org/)."  
#   
#   
##############################################################################  
"""Squishfile objects"""
  
__version__='$Revision: 1.2 $'[11:-2]  
  
import string, time, re  
from Globals import Persistent  
from Acquisition import Acquirer  
from Globals import HTML  
from ImageFile import ImageFile  
from AccessControl.Role import RoleManager
import Globals
#from creosote import spew  
  
sep=re.compile(r'[\\/:]')  # handle windows(\)/unix(/)/mac(:) path separators  
  
class Squishfile(Acquirer,Persistent):  
    """ """  

    __ac_permissions__=(
        ('View',
         ['file_name', 'file_type', 'content_type', 'file_bytes', 'file_kbytes', 'date_created', 'date_modified','icon','index_html'],
         ('Anonymous', 'Manager')),
         )

    # protected by 'View' permission
    def icon(self):
        return 'misc_/Squishdot/squishfile_img'
    
    _types={'application/octet-stream':     'Binary File',  
            'application/x-gzip' :          'Compressed File',  
            'application/x-compress':       'Compressed File',  
            'application/x-zip-compressed': 'Compressed File',  
            'audio/basic':     'Audio File',  
            'audio/x-aiff':    'Audio File',  
            'audio/x-wav' :    'Audio File',  
            'text/html':       'HTML Document',  
            'text/asp':        'Active Server Document',  
            'text/plain':      'Text Document',  
            'image/x-ms-bmp':  'Bitmap Image',  
            'image/bmp' :      'Bitmap Image',  
            'image/gif' :      'GIF Image',  
            'image/jpeg':      'JPEG Image',  
            'image/x-png':     'PNG Image',  
            'image/x-tiff':    'TIFF Image',  
            'video/x-msvideo': 'Video File',  
            'video/mpeg':      'Video File',  
            'video/quicktime': 'Video File',  
          }  
  
    def __init__(self,file=''):  
        if file:  
            self._file    =file.read()  
            #spew('sqf len: ' + str(len(self._file)))  
            name=string.strip(sep.split(file.filename)[-1])  
            name=string.split(name, ' ')  
            name=string.join(name, '_')  
            self._name=name  
            #spew('sqf name: ' + self._name)  
            self._ctype   =string.strip(file.headers['content-type'])  
            #spew('sqf ctype: ' + self._ctype)  
            self._created =time.time()  
            self._modified=self._created  
  
    # protected by 'View' permission
    def content_type(self):  
        """ content type """  
        return self._ctype  
  
    # protected by 'View' permission
    def file_name(self):  
        return self._name  
  
    # protected by 'View' permission
    def file_bytes(self):  
        return len(self._file)  
  
    # protected by 'View' permission
    def file_kbytes(self):  
        return int(len(self._file)/1024)  
  
    file_type__roles__=[]
    def file_type(self):  
        try:    return self._types[self._ctype]  
        except KeyError:  
            f=self._name  
            return '%s File' % string.upper(f[(string.rfind('.', f)+1):])  
  
    # protected by 'View' permission
    def date_created(self):  
        t=time.localtime(self._created)  
        return '%d/%d/%d %02d:%02d' % (t[1],t[2],t[0],t[3],t[4])  
  
    # protected by 'View' permission
    def date_modified(self):  
        t=time.localtime(self._modified)  
        return '%d/%d/%d %02d:%02d' % (t[1],t[2],t[0],t[3],t[4])  
  
    def __len__(self):  
        try:    return len(self._file)  
        except: return 0 # _file doesnt exist  
  
    def __repr__(self, RESPONSE={}):  
        """ """  
        RESPONSE['content-type']=self._ctype  
        return self._file  
  
    # protected by 'View' permission
    index_html=__repr__  

Globals.default__class_init__(Squishfile)
